package com.werken.classworlds;

import junit.framework.TestCase;

public class ClassWorldTest extends TestCase
{
    private ClassWorld world;

    public ClassWorldTest(String name)
    {
        super( name );
    }

    public void setUp()
    {
        this.world = new ClassWorld();
    }

    public void tearDown()
    {
        this.world = null;
    }

    public void testEmpty()
    {
        assertTrue( this.world.getRealms().isEmpty() );
    }

    public void testNewRealm() throws Exception
    {
        ClassRealm realm = this.world.newRealm( "foo" );

        assertNotNull( realm );
    }

    public void testGetRealm() throws Exception
    {
        ClassRealm realm = this.world.newRealm( "foo" );

        assertSame( realm,
                    this.world.getRealm( "foo" ) );
    }

    public void testNewRealm_Duplicate() throws Exception
    {
        try
        {
            this.world.newRealm( "foo" );
            this.world.newRealm( "foo" );

            fail( "throw DuplicateRealmException" );
        }
        catch (DuplicateRealmException e)
        {
            // expected and correct

            assertSame( this.world,
                        e.getWorld() );

            assertEquals( "foo",
                          e.getId() );
        }
    }

    public void testGetRealm_NoSuch() throws Exception
    {
        try
        {
            this.world.getRealm( "foo" );
        }
        catch (NoSuchRealmException e)
        {
            // expected and correct

            assertSame( this.world,
                        e.getWorld() );

            assertEquals( "foo",
                          e.getId() );
        }
    }

    public void testGetRealms() throws Exception
    {
        assertTrue( this.world.getRealms().isEmpty() );

        ClassRealm foo = this.world.newRealm( "foo" );

        assertEquals( 1,
                      this.world.getRealms().size() );

        assertTrue( this.world.getRealms().contains( foo ) );

        ClassRealm bar = this.world.newRealm( "bar" );

        assertEquals( 2,
                      this.world.getRealms().size() );

        assertTrue( this.world.getRealms().contains( bar ) );
    }
}
