package com.werken.classworlds;

import junit.framework.TestCase;

import java.io.File;

public class LauncherTest extends TestCase
{
    private Launcher launcher;

    public LauncherTest(String name)
    {
        super( name );
    }

    public void setUp()
    {
        this.launcher = new Launcher();
    }

    public void tearDown()
    {
        this.launcher = null;
    }

    public void testConfigure_Valid() throws Exception
    {
        launcher.configure( getConfigPath( "valid-launch.conf" ) );

        Class mainClass = launcher.getMainClass();

        assertNotNull( mainClass );

        assertEquals( "a.A",
                      mainClass.getName() );

        assertEquals( "app",
                      launcher.getMainRealm().getId() );
    }

    public void testLaunch_ValidStandard() throws Exception
    {
        launcher.configure( getConfigPath( "valid-launch.conf" ) );

        launcher.launch( new String[]{} );
    }

    public void testLaunch_ValidEnhanced() throws Exception
    {
        launcher.configure( getConfigPath( "valid-enh-launch.conf" ) );

        launcher.launch( new String[]{} );
    }

    public void testLaunch_NoSuchMethod() throws Exception
    {
        launcher.configure( getConfigPath( "launch-nomethod.conf" ) );

        try
        {
            launcher.launch( new String[]{} );
            fail( "throw NoSuchMethodException" );
        }
        catch (NoSuchMethodException e)
        {
            // expected and correct
        }
    }

    public void testLaunch_ClassNotFound() throws Exception
    {
        launcher.configure( getConfigPath( "launch-noclass.conf" ) );

        try
        {
            launcher.launch( new String[]{} );
            fail( "throw ClassNotFoundException" );
        }
        catch (ClassNotFoundException e)
        {
            // expected and correct
        }
    }

    private String getConfigPath(String name)
    {
        return new File( new File( System.getProperty( "basedir" ),
                                   "test-data" ),
                         name ).getPath();
    }
}
